@@ -84,7 +84,7 @@ SimpleResourceGraph PopplerExtractor::extract(const QUrl& resUri, const QUrl& fi
         fileRes.addProperty( NIE::subject(), subject );
     }
 
-    QString creator = pdfDoc->info(QLatin1String("Creator"));
+    QString creator = pdfDoc->info(QLatin1String("Author"));
     if( !creator.isEmpty() ) {
         SimpleResource res;
         res.addType( NCO::Contact() );
@@ -94,8 +94,22 @@ SimpleResourceGraph PopplerExtractor::extract(const QUrl& resUri, const QUrl& fi
         fileRes.addProperty( NCO::creator(), res );
     }
 
+    QString generator = pdfDoc->info(QLatin1String("Creator"));
+    if( !creator.isEmpty() ) {
+        SimpleResource res;
+        res.addType( NCO::Contact() );
+        res.addProperty( NCO::fullname(), creator );
+        graph << res;
+
+        fileRes.addProperty( NIE::generator(), res );
+    }
+
     QString plainTextContent;
     for( int i=0; i<pdfDoc->numPages(); i++ ) {
+        if( plainTextContent.size() >= maxPlainTextSize() ) {
+            break;
+        }
+
         Poppler::Page* page = pdfDoc->page( i );
         if(!page) {  // broken pdf files do not return a valid page
             kWarning() << "Could not read page content from" << fileUrl;
@@ -190,6 +204,9 @@ QString PopplerExtractor::parseFirstPage(Poppler::Document* pdfDoc, const QUrl&
         }
     }
 
+    // FIXME: Sometimes the titles that are extracted are too large. This is a way of trimming them
+    //        though it still gives strange titles.
+    newPossibleTitle.resize( 50 );
     return newPossibleTitle;
 }
 
